@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 try:
     import bpython  # noqa
     # Access a property to verify module exists in case
@@ -65,10 +63,13 @@ class SetPropagatingDict(dict):
 custom_shell_dict = {}
 
 
-def run_classic_shell(globals, locals, first_time=[True]):
-    if first_time:
+SHELL_FIRST_TIME = [True]
+
+
+def run_classic_shell(globals, locals):
+    if SHELL_FIRST_TIME:
         banner = "Hit Ctrl-D to return to PuDB."
-        first_time.pop()
+        SHELL_FIRST_TIME.pop()
     else:
         banner = ""
 
@@ -94,7 +95,7 @@ def run_classic_shell(globals, locals, first_time=[True]):
         readline.clear_history()
         try:
             readline.read_history_file(hist_file)
-        except IOError:
+        except OSError:
             pass
 
     from code import InteractiveConsole
@@ -109,8 +110,8 @@ def run_classic_shell(globals, locals, first_time=[True]):
 def run_bpython_shell(globals, locals):
     ns = SetPropagatingDict([locals, globals], locals)
 
-    import bpython.cli
-    bpython.cli.main(args=[], locals_=ns)
+    import bpython
+    bpython.embed(args=[], locals_=ns)
 
 
 # {{{ ipython
@@ -144,11 +145,11 @@ def ipython_version():
         return None
 
 
-def run_ipython_shell_v10(globals, locals, first_time=[True]):
+def run_ipython_shell_v10(globals, locals):
     """IPython shell from IPython version 0.10"""
-    if first_time:
+    if SHELL_FIRST_TIME:
         banner = "Hit Ctrl-D to return to PuDB."
-        first_time.pop()
+        SHELL_FIRST_TIME.pop()
     else:
         banner = ""
 
@@ -168,7 +169,7 @@ def _update_ipython_ns(shell, globals, locals):
     try:
         shell.user_global_ns = globals
     except AttributeError:
-        class DummyMod(object):
+        class DummyMod:
             """A dummy module used for IPython's interactive namespace."""
             pass
 
@@ -176,15 +177,16 @@ def _update_ipython_ns(shell, globals, locals):
         user_module.__dict__ = globals
         shell.user_module = user_module
 
+    shell.init_history()
     shell.init_user_ns()
     shell.init_completer()
 
 
-def run_ipython_shell_v11(globals, locals, first_time=[True]):
+def run_ipython_shell_v11(globals, locals):
     """IPython shell from IPython version 0.11"""
-    if first_time:
+    if SHELL_FIRST_TIME:
         banner = "Hit Ctrl-D to return to PuDB."
-        first_time.pop()
+        SHELL_FIRST_TIME.pop()
     else:
         banner = ""
 
@@ -231,13 +233,33 @@ def run_ipython_shell(globals, locals):
     else:
         return run_ipython_shell_v11(globals, locals)
 
+
+def run_ipython_kernel(globals, locals):
+    from IPython import embed_kernel
+
+    class DummyMod:
+        pass
+
+    user_module = DummyMod()
+    user_module.__dict__ = globals
+    embed_kernel(module=user_module, local_ns=locals)
+
 # }}}
 
 
+def get_ptpython_history_file():
+    from argparse import ArgumentParser
+    from ptpython.entry_points.run_ptpython import (  # pylint: disable=import-error
+            get_config_and_history_file)
+    parser = ArgumentParser()
+    parser.add_argument("--history_file")
+    parser.add_argument("--config_file")
+    return get_config_and_history_file(parser.parse_args([]))[1]
+
+
 def run_ptpython_shell(globals, locals):
     # Use the default ptpython history
-    import os
-    history_filename = os.path.expanduser("~/.ptpython/history")
+    history_filename = get_ptpython_history_file()
     ptpython_embed(globals=globals.copy(), locals=locals.copy(),
                    history_filename=history_filename,
                    configure=run_config)
@@ -245,9 +267,7 @@ def run_ptpython_shell(globals, locals):
 
 def run_ptipython_shell(globals, locals):
     # Use the default ptpython history
-    import os
-
-    history_filename = os.path.expanduser("~/.ptpython/history")
+    history_filename = get_ptpython_history_file()
     ptipython_embed(globals=globals.copy(), locals=locals.copy(),
                    history_filename=history_filename,
                    configure=run_config)
