@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
 from pudb.lowlevel import detect_encoding, decode_lines
-from pudb.py3compat import PY3
 
 
 def test_detect_encoding_nocookie():
-    lines = [u"Test Проверка"]
+    lines = ["Test Проверка"]
     lines = [line.encode("utf-8") for line in lines]
     encoding, _ = detect_encoding(iter(lines))
     assert encoding == "utf-8"
@@ -12,9 +10,9 @@ def test_detect_encoding_nocookie():
 
 def test_detect_encoding_cookie():
     lines = [
-        u"# coding=utf-8",
-        u"Test",
-        u"Проверка"
+        "# coding=utf-8",
+        "Test",
+        "Проверка"
     ]
     lines = [line.encode("utf-8") for line in lines]
     encoding, _ = detect_encoding(iter(lines))
@@ -23,16 +21,12 @@ def test_detect_encoding_cookie():
 
 def test_decode_lines():
     unicode_lines = [
-        u"# coding=utf-8",
-        u"Test",
-        u"Проверка",
+        "# coding=utf-8",
+        "Test",
+        "Проверка",
     ]
     lines = [line.encode("utf-8") for line in unicode_lines]
-    if PY3:
-        assert unicode_lines == list(decode_lines(iter(lines)))
-    else:
-        assert [line.decode("utf-8")
-                for line in lines] == list(decode_lines(iter(lines)))
+    assert unicode_lines == list(decode_lines(iter(lines)))
 
 
 # {{{ remove common indentation
@@ -83,22 +77,15 @@ def test_executable_lines():
         main()
         """
 
-    assert get_exec_lines(test_code) == set([1, 2, 3, 4, 6, 8])
+    assert get_exec_lines(test_code) == {1, 2, 3, 4, 6, 8}
 
     test_code = "a = 3*5\n" + 333 * "\n" + "b = 15"
-    if PY3:
-        assert get_exec_lines(test_code) == set([
-            1,
-            128,  # bogus,
-            255,  # bogus,
-            335
-            ])
-    else:
-        assert get_exec_lines(test_code) == set([
-            1,
-            256,  # bogus,
-            335
-            ])
+    assert get_exec_lines(test_code) == {
+        1,
+        128,  # bogus,
+        255,  # bogus,
+        335
+        }
 
 
 if __name__ == "__main__":
